# IGNITE-26 Created InternalFuture.

Project: http://git-wip-us.apache.org/repos/asf/incubator-ignite/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-ignite/commit/90948e67
Tree: http://git-wip-us.apache.org/repos/asf/incubator-ignite/tree/90948e67
Diff: http://git-wip-us.apache.org/repos/asf/incubator-ignite/diff/90948e67

Branch: refs/heads/ignite-26-2
Commit: 90948e67ae229b3e68af77bf3750b4116e389550
Parents: 3cbcf92
Author: sevdokimov <sevdoki...@gridgain.com>
Authored: Wed Dec 17 19:16:28 2014 +0300
Committer: sevdokimov <sevdoki...@gridgain.com>
Committed: Wed Dec 17 19:16:31 2014 +0300

----------------------------------------------------------------------
 .../ComputeFibonacciContinuationExample.java    |  11 +-
 .../compute/ComputeRunnableExample.java         |   5 +-
 .../examples/datagrid/CacheApiExample.java      |   7 +-
 .../examples/ScalarContinuationExample.scala    |   8 +-
 .../singlesplit/GridSingleSplitsLoadTest.java   |   3 +-
 .../spi/checkpoint/s3/GridS3CheckpointSpi.java  |   2 +-
 .../ipfinder/s3/GridTcpDiscoveryS3IpFinder.java |   4 +-
 .../s3/GridS3CheckpointSpiSelfTest.java         |   4 +-
 ...GridClientAbstractMultiThreadedSelfTest.java |   7 +-
 .../client/GridClientStartNodeTask.java         |   5 +-
 .../rest/GridRestProcessorStartSelfTest.java    |   2 +-
 .../java/org/apache/ignite/IgniteCompute.java   |  75 +++---
 .../org/apache/ignite/IgniteDataLoader.java     |  34 +--
 .../java/org/apache/ignite/IgniteScheduler.java |   4 +-
 .../apache/ignite/IgniteSystemProperties.java   |   7 +-
 .../cluster/ClusterTopologyException.java       |   2 +-
 .../org/apache/ignite/compute/ComputeJob.java   |   4 +-
 .../apache/ignite/compute/ComputeJobResult.java |   2 +-
 .../org/apache/ignite/compute/ComputeTask.java  |  10 +-
 .../ignite/compute/ComputeTaskAdapter.java      |   3 +-
 .../ignite/compute/ComputeTaskFuture.java       |   6 +-
 .../ignite/compute/ComputeTaskSession.java      |   2 +-
 .../compute/ComputeTaskTimeoutException.java    |   2 +-
 .../compute/InternalComputeTaskFuture.java      |  52 ++++
 .../apache/ignite/fs/mapreduce/IgniteFsJob.java |   4 +-
 .../ignite/lang/IgniteAsyncSupportAdapter.java  |   4 +-
 .../org/apache/ignite/lang/IgniteFuture.java    |  40 +--
 .../lang/IgniteFutureCancelledException.java    |   2 +-
 .../org/apache/ignite/lang/InternalFuture.java  | 182 +++++++++++++
 .../lang/InternalFutureCancelledException.java  |  50 ++++
 .../lang/InternalFutureTimeoutException.java    |  50 ++++
 .../IgniteOptimizedObjectStreamRegistry.java    |  14 +-
 .../ignite/scheduler/SchedulerFuture.java       |  12 +-
 .../communication/tcp/TcpCommunicationSpi.java  |   2 +-
 .../discovery/tcp/TcpClientDiscoverySpi.java    |  10 +-
 .../spi/discovery/tcp/TcpDiscoverySpi.java      |  12 +-
 .../discovery/tcp/TcpDiscoverySpiAdapter.java   |   2 +-
 .../ipfinder/jdbc/TcpDiscoveryJdbcIpFinder.java |   2 +-
 .../TcpDiscoveryMulticastIpFinder.java          |   2 +-
 .../sharedfs/TcpDiscoverySharedFsIpFinder.java  |   2 +-
 .../spi/swapspace/file/FileSwapSpaceSpi.java    |   6 +-
 .../window/StreamerBoundedSizeBatchWindow.java  |  10 +-
 .../window/StreamerBoundedTimeBatchWindow.java  |  10 +-
 .../impl/GridClientAbstractProjection.java      |   4 +-
 .../gridgain/grid/GridDeploymentException.java  |   2 +-
 .../gridgain/grid/GridInterruptedException.java |  50 ----
 .../grid/IgniteInterruptedException.java        |  50 ++++
 .../grid/InternalInterruptedException.java      |  50 ++++
 .../java/org/gridgain/grid/cache/GridCache.java |   4 +-
 .../org/gridgain/grid/cache/GridCacheEntry.java |  28 +-
 .../grid/cache/GridCacheProjection.java         |  46 ++--
 .../org/gridgain/grid/cache/GridCacheTx.java    |   2 +-
 ...GridCacheConsistentHashAffinityFunction.java |   2 +-
 .../datastructures/GridCacheCountDownLatch.java |  12 +-
 .../grid/cache/query/GridCacheQueries.java      |   6 +-
 .../grid/cache/query/GridCacheQueryFuture.java  |   2 +-
 .../org/gridgain/grid/hadoop/GridHadoop.java    |   4 +-
 .../gridgain/grid/hadoop/GridHadoopTask.java    |   2 +-
 .../grid/kernal/ComputeTaskFutureAdapter.java   |  29 +++
 .../java/org/gridgain/grid/kernal/GridEx.java   |   2 +-
 .../grid/kernal/GridJobSessionImpl.java         |   6 +-
 .../org/gridgain/grid/kernal/GridKernal.java    |  18 +-
 .../grid/kernal/GridTaskFutureImpl.java         |   2 +-
 .../grid/kernal/GridTaskSessionImpl.java        |   2 +-
 .../gridgain/grid/kernal/IgniteComputeImpl.java |  78 +++---
 .../grid/kernal/IgniteFutureAdapter.java        | 175 +++++++++++++
 .../grid/kernal/IgniteSchedulerImpl.java        |   4 +-
 .../org/gridgain/grid/kernal/KernalFuture.java  |  16 ++
 .../kernal/executor/GridExecutorService.java    |  49 ++--
 .../grid/kernal/ggfs/common/GridGgfsLogger.java |   4 +-
 .../discovery/GridDiscoveryManager.java         |   4 +-
 .../eventstorage/GridEventStorageManager.java   |   4 +-
 .../affinity/GridAffinityAssignmentCache.java   |   5 +-
 .../affinity/GridAffinityProcessor.java         |   8 +-
 .../processors/cache/GridCacheAdapter.java      | 254 +++++++++----------
 .../cache/GridCacheAffinityManager.java         |   6 +-
 .../processors/cache/GridCacheContext.java      |  13 +-
 .../processors/cache/GridCacheEntryImpl.java    |  28 +-
 .../cache/GridCacheEvictionEntry.java           |  28 +-
 .../cache/GridCacheEvictionManager.java         |   8 +-
 .../cache/GridCacheExplicitLockSpan.java        |   2 +-
 .../cache/GridCacheFilterEvaluationEntry.java   |  28 +-
 .../processors/cache/GridCacheFuture.java       |   2 +-
 .../processors/cache/GridCacheIoManager.java    |  14 +-
 .../cache/GridCacheMultiTxFuture.java           |   4 +-
 .../processors/cache/GridCacheMvccManager.java  |  29 +--
 .../GridCachePartitionExchangeManager.java      |  18 +-
 .../processors/cache/GridCachePreloader.java    |   6 +-
 .../cache/GridCachePreloaderAdapter.java        |   9 +-
 .../processors/cache/GridCacheProcessor.java    |   8 +-
 .../processors/cache/GridCacheProjectionEx.java |  22 +-
 .../cache/GridCacheProjectionImpl.java          |  68 ++---
 .../processors/cache/GridCacheProxyImpl.java    |  72 +++---
 .../cache/GridCacheSharedContext.java           |  11 +-
 .../processors/cache/GridCacheTtlManager.java   |   2 +-
 .../processors/cache/GridCacheTxAdapter.java    |   5 +-
 .../kernal/processors/cache/GridCacheTxEx.java  |   6 +-
 .../processors/cache/GridCacheTxHandler.java    |  47 ++--
 .../cache/GridCacheTxLocalAdapter.java          |  86 +++----
 .../processors/cache/GridCacheTxLocalEx.java    |  18 +-
 .../processors/cache/GridCacheTxManager.java    |  14 +-
 .../processors/cache/GridCacheTxProxyImpl.java  |   2 +-
 .../kernal/processors/cache/GridCacheUtils.java |   7 +-
 .../cache/GridCacheWriteBehindStore.java        |  10 +-
 .../GridCacheAtomicSequenceImpl.java            |   3 +-
 ...ridCacheOptimisticCheckPreparedTxFuture.java |   7 +-
 ...dCachePessimisticCheckCommittedTxFuture.java |   6 +-
 .../distributed/GridCacheTxFinishSync.java      |   7 +-
 .../GridDistributedCacheAdapter.java            |   6 +-
 .../GridDistributedTxRemoteAdapter.java         |   6 +-
 .../distributed/dht/GridDhtCacheAdapter.java    |  12 +-
 .../distributed/dht/GridDhtCacheEntry.java      |   6 +-
 .../distributed/dht/GridDhtEmbeddedFuture.java  |   8 +-
 .../cache/distributed/dht/GridDhtFuture.java    |   2 +-
 .../cache/distributed/dht/GridDhtGetFuture.java |  10 +-
 .../distributed/dht/GridDhtLocalPartition.java  |   6 +-
 .../distributed/dht/GridDhtLockFuture.java      |  11 +-
 .../distributed/dht/GridDhtTopologyFuture.java  |   2 +-
 .../dht/GridDhtTransactionalCacheAdapter.java   |  28 +-
 .../distributed/dht/GridDhtTxFinishFuture.java  |  11 +-
 .../cache/distributed/dht/GridDhtTxLocal.java   |  20 +-
 .../distributed/dht/GridDhtTxLocalAdapter.java  |  10 +-
 .../distributed/dht/GridDhtTxPrepareFuture.java |  12 +-
 .../dht/GridPartitionedGetFuture.java           |  21 +-
 .../dht/atomic/GridDhtAtomicCache.java          |  86 +++----
 .../dht/atomic/GridNearAtomicUpdateFuture.java  |   5 +-
 .../dht/colocated/GridDhtColocatedCache.java    |  20 +-
 .../colocated/GridDhtColocatedLockFuture.java   |  23 +-
 .../dht/preloader/GridDhtForceKeysFuture.java   |   8 +-
 .../preloader/GridDhtPartitionDemandPool.java   |  24 +-
 .../preloader/GridDhtPartitionSupplyPool.java   |   2 +-
 .../GridDhtPartitionsExchangeFuture.java        |  24 +-
 .../dht/preloader/GridDhtPreloader.java         |  28 +-
 .../distributed/near/GridNearAtomicCache.java   |  42 +--
 .../distributed/near/GridNearCacheAdapter.java  |  14 +-
 .../distributed/near/GridNearGetFuture.java     |  25 +-
 .../distributed/near/GridNearLockFuture.java    |  23 +-
 .../near/GridNearTransactionalCache.java        |   8 +-
 .../near/GridNearTxFinishFuture.java            |  17 +-
 .../cache/distributed/near/GridNearTxLocal.java |  60 ++---
 .../near/GridNearTxPrepareFuture.java           |  17 +-
 .../processors/cache/local/GridLocalCache.java  |   6 +-
 .../processors/cache/local/GridLocalTx.java     |  12 +-
 .../local/atomic/GridLocalAtomicCache.java      |  58 ++---
 .../GridCacheDistributedFieldsQueryFuture.java  |   2 +-
 .../query/GridCacheDistributedQueryFuture.java  |   2 +-
 .../query/GridCacheDistributedQueryManager.java |  10 +-
 .../query/GridCacheFieldsQueryErrorFuture.java  |   2 +-
 .../query/GridCacheLocalFieldsQueryFuture.java  |   2 +-
 .../cache/query/GridCacheLocalQueryFuture.java  |   2 +-
 .../cache/query/GridCacheQueriesImpl.java       |   6 +-
 .../cache/query/GridCacheQueriesProxy.java      |   6 +-
 .../query/GridCacheQueryFutureAdapter.java      |   6 +-
 .../cache/query/GridCacheQueryManager.java      |  50 ++--
 .../query/GridCacheQueryMetadataAware.java      |   2 +-
 .../GridCacheContinuousQueryEntry.java          |  28 +-
 .../clock/GridClockDeltaSnapshot.java           |   6 +-
 .../processors/clock/GridClockServer.java       |   2 +-
 .../clock/GridClockSyncProcessor.java           |   2 +-
 .../closure/GridClosureProcessor.java           |  56 ++--
 .../continuous/GridContinuousProcessor.java     |   8 +-
 .../dataload/GridDataLoadUpdateJob.java         |   2 +-
 .../dataload/GridDataLoaderProcessor.java       |   8 +-
 .../dataload/IgniteDataLoaderImpl.java          |  75 +++---
 .../dr/GridDrDataLoadCacheUpdater.java          |   3 +-
 .../email/GridEmailProcessorAdapter.java        |   5 +-
 .../email/GridNoopEmailProcessor.java           |   4 +-
 .../processors/ggfs/GridGgfsAsyncImpl.java      |   3 +-
 .../processors/ggfs/GridGgfsDataManager.java    |  40 +--
 .../processors/ggfs/GridGgfsDeleteWorker.java   |   4 +-
 .../grid/kernal/processors/ggfs/GridGgfsEx.java |   3 +-
 .../ggfs/GridGgfsFileWorkerBatch.java           |   2 +-
 .../ggfs/GridGgfsFragmentizerManager.java       |   6 +-
 .../kernal/processors/ggfs/GridGgfsImpl.java    |  17 +-
 .../ggfs/GridGgfsInputStreamImpl.java           |  19 +-
 .../processors/ggfs/GridGgfsIpcHandler.java     |   5 +-
 .../processors/ggfs/GridGgfsMetaManager.java    |  10 +-
 .../kernal/processors/ggfs/GridGgfsServer.java  |  10 +-
 .../processors/ggfs/GridGgfsServerHandler.java  |   2 +-
 .../ggfs/IgniteFsOutputStreamImpl.java          |   3 +-
 .../hadoop/GridHadoopNoopProcessor.java         |   4 +-
 .../hadoop/GridHadoopProcessorAdapter.java      |   4 +-
 .../kernal/processors/job/GridJobWorker.java    |   4 +-
 .../processors/query/GridQueryProcessor.java    |  12 +-
 .../processors/rest/GridRestProcessor.java      |  18 +-
 .../rest/GridRestProtocolHandler.java           |   2 +-
 .../rest/handlers/GridRestCommandHandler.java   |   2 +-
 .../handlers/cache/GridCacheCommandHandler.java |  55 ++--
 .../cache/GridCacheQueryCommandHandler.java     |  13 +-
 .../handlers/log/GridLogCommandHandler.java     |   2 +-
 .../metadata/GridPortableMetadataHandler.java   |   3 +-
 .../handlers/task/GridTaskCommandHandler.java   |  15 +-
 .../top/GridTopologyCommandHandler.java         |   2 +-
 .../version/GridVersionCommandHandler.java      |   2 +-
 .../tcp/GridTcpMemcachedNioListener.java        |  17 +-
 .../protocols/tcp/GridTcpRestNioListener.java   |   5 +-
 .../service/GridServiceProcessor.java           |  24 +-
 .../processors/streamer/IgniteStreamerImpl.java |  16 +-
 .../processors/task/GridTaskProcessor.java      |  22 +-
 .../visor/cache/VisorCachePreloadTask.java      |   4 +-
 .../compute/VisorComputeCancelSessionsTask.java |   5 +-
 .../grid/util/GridAtomicInitializer.java        |   4 +-
 .../java/org/gridgain/grid/util/GridUtils.java  | 103 +++++---
 .../grid/util/future/GridCompoundFuture.java    |  30 +--
 .../util/future/GridCompoundIdentityFuture.java |   2 +-
 .../grid/util/future/GridEmbeddedFuture.java    |  38 +--
 .../grid/util/future/GridFinishedFuture.java    |   9 +-
 .../grid/util/future/GridFinishedFutureEx.java  |   8 +-
 .../grid/util/future/GridFutureAdapter.java     |  42 +--
 .../grid/util/future/GridFutureAdapterEx.java   |  42 +--
 .../util/future/GridFutureChainListener.java    |   8 +-
 .../GridIpcSharedMemoryServerEndpoint.java      |   6 +-
 .../org/gridgain/grid/util/lang/GridFunc.java   |  64 ++---
 .../grid/util/lang/GridPlainFuture.java         |   3 +-
 .../grid/util/lang/GridPlainFutureAdapter.java  |   2 +-
 .../gridgain/grid/util/nio/GridNioFuture.java   |  18 +-
 .../grid/util/nio/GridNioFutureImpl.java        |  12 +-
 .../gridgain/grid/util/nio/GridNioServer.java   |  10 +-
 .../java/org/gridgain/grid/util/typedef/X.java  |   5 +-
 .../gridgain/grid/util/worker/GridWorker.java   |   6 +-
 ...redFsCheckpointSpiMultiThreadedSelfTest.java |   6 +-
 .../collision/GridTestCollisionTaskSession.java |   2 +-
 .../tcp/GridOrderedMessageCancelSelfTest.java   |   6 +-
 ...mmunicationSpiConcurrentConnectSelfTest.java |   2 +-
 .../tcp/GridTcpCommunicationSpiLanTest.java     |   2 +-
 ...cpCommunicationSpiMultithreadedSelfTest.java |  10 +-
 ...GridTcpCommunicationSpiRecoverySelfTest.java |   6 +-
 .../tcp/GridTcpDiscoveryMultiThreadedTest.java  |   4 +-
 .../file/GridFileSwapSpaceSpiSelfTest.java      |   6 +-
 .../index/GridStreamerIndexSelfTest.java        |   8 +-
 .../window/GridStreamerWindowSelfTest.java      |   2 +-
 .../GridCacheStoreValueBytesTest.java           |   6 +-
 .../org/gridgain/grid/GridTestTaskSession.java  |   2 +-
 .../store/GridCacheBalancingStoreSelfTest.java  |   2 +-
 ...CacheJdbcBlobStoreMultithreadedSelfTest.java |   4 +-
 .../kernal/GridCancelOnGridStopSelfTest.java    |   3 +-
 .../kernal/GridCancelUnusedJobSelfTest.java     |   3 +-
 .../GridCancelledJobsMetricsSelfTest.java       |   5 +-
 .../grid/kernal/GridContinuousTaskSelfTest.java |  11 +-
 .../GridDeploymentMultiThreadedSelfTest.java    |   3 +-
 .../grid/kernal/GridDeploymentSelfTest.java     |   9 +-
 .../GridEventStorageCheckAllEventsSelfTest.java |   7 +-
 .../GridExplicitImplicitDeploymentSelfTest.java |   3 +-
 .../GridFailoverCustomTopologySelfTest.java     |   5 +-
 .../GridJobCheckpointCleanupSelfTest.java       |   3 +-
 .../kernal/GridJobCollisionCancelSelfTest.java  |   3 +-
 .../kernal/GridJobMasterLeaveAwareSelfTest.java |  64 ++---
 .../grid/kernal/GridJobStealingSelfTest.java    |   3 +-
 .../GridJobStealingZeroActiveJobsSelfTest.java  |   3 +-
 .../grid/kernal/GridJobSubjectIdSelfTest.java   |   3 +-
 .../grid/kernal/GridMultipleJobsSelfTest.java   |   7 +-
 .../grid/kernal/GridMultipleSpisSelfTest.java   |   3 +-
 .../GridMultipleVersionsDeploymentSelfTest.java |   9 +-
 .../GridMultithreadedJobStealingSelfTest.java   |   3 +-
 .../grid/kernal/GridProjectionAbstractTest.java |  29 +--
 .../grid/kernal/GridReduceSelfTest.java         |   2 +-
 .../kernal/GridRuntimeExceptionSelfTest.java    |  11 +-
 .../grid/kernal/GridStopWithCancelSelfTest.java |   3 +-
 .../grid/kernal/GridStopWithWaitSelfTest.java   |   7 +-
 .../GridTaskCancelSingleNodeSelfTest.java       |   5 +-
 .../GridTaskContinuousMapperSelfTest.java       |   7 +-
 .../grid/kernal/GridTaskExecutionSelfTest.java  |   2 +-
 .../grid/kernal/GridTaskFailoverSelfTest.java   |   3 +-
 .../GridTaskFutureImplStopGridSelfTest.java     |   7 +-
 .../GridTaskInstanceExecutionSelfTest.java      |   2 +-
 .../kernal/GridTaskInstantiationSelfTest.java   |   2 +-
 .../grid/kernal/GridTaskJobRejectSelfTest.java  |   5 +-
 .../grid/kernal/GridTaskListenerSelfTest.java   |   7 +-
 .../grid/kernal/GridTaskTimeoutSelfTest.java    |   7 +-
 .../GridCheckpointManagerAbstractSelfTest.java  |   6 +-
 .../GridDeploymentMessageCountSelfTest.java     |   2 +-
 .../events/GridEventStorageManagerSelfTest.java |   6 +-
 .../GridCacheAbstractFailoverSelfTest.java      |   3 +-
 .../cache/GridCacheAbstractFlagsTest.java       |   2 +-
 ...cheAbstractFullApiMultithreadedSelfTest.java |   4 +-
 .../cache/GridCacheAbstractFullApiSelfTest.java |  85 +++----
 .../GridCacheAbstractIteratorsSelfTest.java     |   8 +-
 .../GridCacheAbstractRemoveFailureTest.java     |   5 +-
 .../GridCacheAsyncOperationsLimitSelfTest.java  |   6 +-
 .../cache/GridCacheConcurrentMapTest.java       |   4 +-
 .../GridCacheConcurrentTxMultiNodeTest.java     |   5 +-
 .../GridCacheFinishPartitionsSelfTest.java      |  22 +-
 ...CacheFullTextQueryMultithreadedSelfTest.java |   4 +-
 ...idCacheGetAndTransformStoreAbstractTest.java |   2 +-
 .../GridCacheGroupLockAbstractSelfTest.java     |   3 +-
 .../GridCacheGroupLockFailoverSelfTest.java     |  11 +-
 .../cache/GridCacheGroupLockPutTask.java        |   3 +-
 .../cache/GridCacheIncrementTransformTest.java  |   2 +-
 .../cache/GridCacheLuceneQueryIndexTest.java    |  16 +-
 .../GridCacheMissingCommitVersionSelfTest.java  |   4 +-
 ...GridCacheMixedPartitionExchangeSelfTest.java |   4 +-
 .../cache/GridCacheMultiUpdateLockSelfTest.java |   2 +-
 ...HeapMultiThreadedUpdateAbstractSelfTest.java |   4 +-
 .../GridCachePreloadingEvictionsSelfTest.java   |   6 +-
 .../cache/GridCachePutAllFailoverSelfTest.java  |  27 +-
 .../GridCacheReferenceCleanupSelfTest.java      |   4 +-
 ...ridCacheReplicatedSynchronousCommitTest.java |   2 +-
 .../processors/cache/GridCacheStopSelfTest.java |   4 +-
 .../cache/GridCacheSwapPreloadSelfTest.java     |   2 +-
 .../cache/GridCacheTtlManagerLoadTest.java      |   2 +-
 .../GridCacheTxMultiThreadedAbstractTest.java   |   5 +-
 .../GridCacheVariableTopologySelfTest.java      |   2 +-
 ...idCacheWriteBehindStoreAbstractSelfTest.java |   2 +-
 .../GridCacheWriteBehindStoreAbstractTest.java  |   2 +-
 ...BehindStorePartitionedMultiNodeSelfTest.java |   4 +-
 .../GridCacheWriteBehindStoreSelfTest.java      |   4 +-
 ...eAbstractDataStructuresFailoverSelfTest.java |  26 +-
 ...actQueueFailoverDataConsistencySelfTest.java |   6 +-
 .../GridCacheCountDownLatchSelfTest.java        |   6 +-
 .../GridCacheQueueCleanupSelfTest.java          |   2 +-
 ...ridCacheQueueJoinedNodeSelfAbstractTest.java |  16 +-
 ...GridCacheQueueMultiNodeAbstractSelfTest.java |  17 +-
 .../GridCacheSetAbstractSelfTest.java           |   6 +-
 .../GridCacheSetFailoverAbstractSelfTest.java   |   4 +-
 ...PartitionedQueueCreateMultiNodeSelfTest.java |   4 +-
 ...dCachePartitionedQueueEntryMoveSelfTest.java |   5 +-
 .../GridCacheAbstractJobExecutionTest.java      |   5 +-
 .../GridCacheAtomicTimeoutSelfTest.java         |   9 +-
 .../GridCacheBasicOpAbstractTest.java           |   7 +-
 .../distributed/GridCacheEventAbstractTest.java |   2 +-
 .../distributed/GridCacheLockAbstractTest.java  |   4 +-
 .../GridCacheMultiNodeAbstractTest.java         |  14 +-
 .../GridCacheMultiNodeLockAbstractTest.java     |   7 +-
 ...dCacheMultithreadedFailoverAbstractTest.java |   3 +-
 .../GridCacheNodeFailureAbstractTest.java       |   5 +-
 ...xOriginatingNodeFailureAbstractSelfTest.java |   2 +-
 ...cOriginatingNodeFailureAbstractSelfTest.java |   4 +-
 .../GridCacheTxPreloadAbstractTest.java         |   2 +-
 .../dht/GridCacheColocatedDebugTest.java        |   7 +-
 ...GridCacheDhtEvictionNearReadersSelfTest.java |   7 +-
 .../dht/GridCacheDhtEvictionSelfTest.java       |   9 +-
 .../dht/GridCacheDhtPreloadDelayedSelfTest.java |   2 +-
 .../dht/GridCacheDhtPreloadPutGetSelfTest.java  |   4 +-
 .../dht/GridCacheDhtPreloadSelfTest.java        |   5 +-
 .../GridCacheDhtPreloadStartStopSelfTest.java   |   3 +-
 ...dCachePartitionedTopologyChangeSelfTest.java |  29 +--
 ...eAtomicInvalidPartitionHandlingSelfTest.java |   4 +-
 .../GridCachePartitionedEntryLockSelfTest.java  |   6 +-
 ...titionedExplicitLockNodeFailureSelfTest.java |   4 +-
 .../near/GridCachePartitionedLockSelfTest.java  |   5 +-
 ...achePartitionedMultiNodeFullApiSelfTest.java |   6 +-
 ...hePartitionedQueryMultiThreadedSelfTest.java |   4 +-
 .../GridCachePartitionedTxSalvageSelfTest.java  |   3 +-
 .../GridCacheReplicatedEvictionSelfTest.java    |   4 +-
 .../GridCacheBatchEvictUnswapSelfTest.java      |   5 +-
 ...heConcurrentEvictionConsistencySelfTest.java |   2 +-
 .../GridCacheConcurrentEvictionsSelfTest.java   |   2 +-
 .../GridCacheEmptyEntriesAbstractSelfTest.java  |   4 +-
 .../cache/eviction/GridCacheMockEntry.java      |  28 +-
 ...cheSynchronousEvictionsFailoverSelfTest.java |   2 +-
 .../GridCacheLocalMultithreadedSelfTest.java    |   8 +-
 .../closure/GridClosureProcessorSelfTest.java   |  27 +-
 .../continuous/GridEventConsumeSelfTest.java    |   9 +-
 .../GridDataLoaderProcessorSelfTest.java        |  25 +-
 ...heGgfsPerBlockLruEvictionPolicySelfTest.java |   2 +-
 .../ggfs/GridGgfsAbstractSelfTest.java          |   8 +-
 .../ggfs/GridGgfsDataManagerSelfTest.java       |   8 +-
 .../processors/ggfs/GridGgfsTaskSelfTest.java   |   5 +-
 .../cache/GridCacheCommandHandlerSelfTest.java  |   2 +-
 .../GridServiceProcessorAbstractSelfTest.java   |  19 +-
 .../GridServiceProcessorMultiNodeSelfTest.java  |   6 +-
 .../streamer/GridStreamerFailoverSelfTest.java  |   2 +-
 .../streamer/GridStreamerSelfTest.java          |   2 +-
 .../timeout/GridTimeoutProcessorSelfTest.java   |   4 +-
 .../grid/lang/GridBasicPerformanceTest.java     |   4 +-
 .../gridgain/grid/lang/GridFuncSelfTest.java    |  13 +-
 .../lang/GridFutureListenPerformanceTest.java   |   4 +-
 .../grid/loadtest/GridLoadTestStatistics.java   |   2 +-
 .../grid/loadtest/GridSingleExecutionTest.java  |   3 +-
 ...idFileSwapSpaceSpiMultithreadedLoadTest.java |   4 +-
 .../marshaller/GridMarshallerAbstractTest.java  |   3 +-
 .../grid/messaging/GridMessagingSelfTest.java   |   4 +-
 .../p2p/GridAbstractMultinodeRedeployTest.java  |   5 +-
 .../grid/p2p/GridP2PTestTaskExecutionTest.java  |   3 +-
 ...SessionCancelSiblingsFromFutureSelfTest.java |   3 +-
 ...ridSessionCancelSiblingsFromJobSelfTest.java |   3 +-
 ...idSessionCancelSiblingsFromTaskSelfTest.java |   3 +-
 .../GridSessionCheckpointAbstractSelfTest.java  |   3 +-
 ...idSessionFutureWaitJobAttributeSelfTest.java |   3 +-
 ...dSessionFutureWaitTaskAttributeSelfTest.java |   3 +-
 ...GridSessionJobWaitTaskAttributeSelfTest.java |   3 +-
 .../GridSessionSetFutureAttributeSelfTest.java  |   3 +-
 ...nSetFutureAttributeWaitListenerSelfTest.java |   3 +-
 .../GridSessionSetJobAttribute2SelfTest.java    |   3 +-
 ...GridSessionSetJobAttributeOrderSelfTest.java |   3 +-
 .../GridSessionSetJobAttributeSelfTest.java     |   3 +-
 ...sionSetJobAttributeWaitListenerSelfTest.java |   3 +-
 .../GridSessionSetTaskAttributeSelfTest.java    |   3 +-
 ...GridSessionTaskWaitJobAttributeSelfTest.java |   3 +-
 .../GridSessionWaitAttributeSelfTest.java       |   3 +-
 ...dConcurrentLinkedDequeMultiThreadedTest.java |   4 +-
 ...rrentLinkedHashMapMultiThreadedSelfTest.java |   8 +-
 .../gridgain/grid/util/GridIndexFillTest.java   |   2 +-
 .../grid/util/GridSnapshotLockSelfTest.java     |   4 +-
 .../util/GridSpinReadWriteLockSelfTest.java     |   2 +-
 .../util/future/GridCompoundFutureSelfTest.java |   6 +-
 .../util/future/GridEmbeddedFutureSelfTest.java |   8 +-
 .../util/future/GridFinishedFutureSelfTest.java |   6 +-
 .../util/future/GridFutureAdapterSelfTest.java  |  38 +--
 .../future/GridFutureListenPerformanceTest.java |   4 +-
 .../util/future/nio/GridNioFutureSelfTest.java  |  10 +-
 .../shmem/GridIpcSharedMemorySpaceSelfTest.java |   5 +-
 .../gridgain/grid/util/nio/GridNioSelfTest.java |   6 +-
 .../offheap/GridOffHeapMapAbstractSelfTest.java |   6 +-
 ...idOffHeapPartitionedMapAbstractSelfTest.java |   2 +-
 ...apPartitionedMapPerformanceAbstractTest.java |   8 +-
 .../unsafe/GridUnsafeMemorySelfTest.java        |   6 +-
 .../org/gridgain/jvmtest/ConcurrentMapTest.java |   2 +-
 .../gridgain/jvmtest/NetworkFailureTest.java    |  14 +-
 .../QueueSizeCounterMultiThreadedTest.java      |   2 +-
 .../jvmtest/ReadWriteLockMultiThreadedTest.java |   8 +-
 .../cache/GridCacheAbstractLoadTest.java        |   5 +-
 .../loadtests/cache/GridCacheSwapLoadTest.java  |  13 +-
 .../GridCacheWriteBehindStoreLoadTest.java      |   2 +-
 .../loadtests/colocation/GridTestMain.java      |   9 +-
 .../communication/GridIoManagerBenchmark.java   |   4 +-
 .../communication/GridIoManagerBenchmark0.java  |  11 +-
 .../GridContinuousOperationsLoadTest.java       |  12 +-
 .../multisplit/GridMultiSplitsLoadTest.java     |   3 +-
 .../GridMultiSplitsRedeployLoadTest.java        |   3 +-
 ...ridSingleSplitsNewNodesAbstractLoadTest.java |   2 +-
 .../GridSingleSplitsRedeployLoadTest.java       |   3 +-
 .../direct/session/GridSessionLoadTest.java     |   2 +-
 .../direct/stealing/GridStealingLoadTest.java   |   2 +-
 .../gridgain/loadtests/dsi/GridDsiClient.java   |   5 +-
 ...GridJobExecutionLoadTestClientSemaphore.java |   7 +-
 ...JobExecutionSingleNodeSemaphoreLoadTest.java |  10 +-
 .../loadtests/job/GridJobLoadTestSubmitter.java |  11 +-
 .../mergesort/GridMergeSortLoadTask.java        |   7 +-
 ...apPartitionedMapPerformanceAbstractTest.java |   8 +-
 .../streamer/GridStreamerIndexLoadTest.java     |   8 +-
 .../loadtests/streamer/QueryClosure.java        |   4 +-
 .../GridTestSafeThreadFactory.java              |   2 +-
 .../gridgain/testframework/GridTestUtils.java   |  20 +-
 .../testframework/junits/GridAbstractTest.java  |   9 +-
 .../cache/GridAbstractCacheStoreSelfTest.java   |   2 +-
 .../junits/common/GridCommonAbstractTest.java   |  17 +-
 .../processors/email/GridEmailProcessor.java    |   4 +-
 .../GridHadoopClientProtocolProvider.java       |   7 +-
 .../kernal/ggfs/hadoop/GridGgfsHadoopIpcIo.java |   2 +-
 .../processors/hadoop/GridHadoopImpl.java       |   5 +-
 .../processors/hadoop/GridHadoopProcessor.java  |   5 +-
 .../hadoop/jobtracker/GridHadoopJobTracker.java |  19 +-
 .../proto/GridHadoopProtocolJobStatusTask.java  |   7 +-
 .../hadoop/shuffle/GridHadoopShuffle.java       |   3 +-
 .../hadoop/shuffle/GridHadoopShuffleJob.java    |  10 +-
 .../taskexecutor/GridHadoopExecutorService.java |   2 +-
 .../GridHadoopExternalTaskExecutor.java         |  17 +-
 .../child/GridHadoopChildProcessRunner.java     |  17 +-
 .../hadoop/v2/GridHadoopV2CleanupTask.java      |   2 +-
 .../hadoop/v2/GridHadoopV2MapTask.java          |   2 +-
 .../hadoop/v2/GridHadoopV2ReduceTask.java       |   2 +-
 .../hadoop/v2/GridHadoopV2SetupTask.java        |   2 +-
 .../hadoop/v2/GridHadoopV2Splitter.java         |   2 +-
 ...idHadoopDefaultMapReducePlannerSelfTest.java |   8 +-
 .../hadoop/GridHadoopJobTrackerSelfTest.java    |   2 +-
 .../GridHadoopMapReduceEmbeddedSelfTest.java    |   2 +-
 .../hadoop/GridHadoopMapReduceTest.java         |   3 +-
 .../hadoop/GridHadoopTaskExecutionSelfTest.java |  11 +-
 .../GridHadoopExecutorServiceTest.java          |   4 +-
 ...GridHadoopExternalTaskExecutionSelfTest.java |   5 +-
 .../ggfs/GridGgfsPerformanceBenchmark.java      |   2 +-
 .../cache/GridCacheOffHeapAndSwapSelfTest.java  |   4 +-
 .../GridCacheQueryMultiThreadedSelfTest.java    |  17 +-
 ...idCacheReduceQueryMultithreadedSelfTest.java |   4 +-
 .../near/GridCacheQueryNodeRestartSelfTest.java |   4 +-
 .../GridCacheReplicatedQuerySelfTest.java       |   3 +-
 .../query/h2/GridH2IndexRebuildTest.java        |  10 +-
 .../query/h2/GridH2IndexingGeoSelfTest.java     |   4 +-
 .../scalar/pimps/ScalarProjectionPimp.scala     |  32 +--
 .../processors/schedule/ScheduleFutureImpl.java |  38 +--
 .../grid/kernal/GridScheduleSelfTest.java       |  13 +-
 .../GridResourceConcurrentUndeploySelfTest.java |   9 +-
 .../util/nodestart/GridNodeCallableImpl.java    |   6 +-
 .../deployment/uri/GridUriDeploymentSpi.java    |   2 +-
 .../GridTaskUriDeploymentDeadlockSelfTest.java  |   2 +-
 .../websession/GridWebSessionSelfTest.java      |   2 +-
 477 files changed, 3080 insertions(+), 2590 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/examples/src/main/java/org/gridgain/examples/compute/ComputeFibonacciContinuationExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeFibonacciContinuationExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeFibonacciContinuationExample.java
index 2246694..4729a24 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeFibonacciContinuationExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeFibonacciContinuationExample.java
@@ -15,7 +15,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
 import org.apache.ignite.resources.*;
 import org.gridgain.examples.*;
-import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
 import java.math.*;
@@ -79,10 +78,10 @@ public final class ComputeFibonacciContinuationExample {
      */
     private static class FibonacciClosure implements IgniteClosure<Long, 
BigInteger> {
         /** Future for spawned task. */
-        private IgniteFuture<BigInteger> fut1;
+        private InternalFuture<BigInteger> fut1;
 
         /** Future for spawned task. */
-        private IgniteFuture<BigInteger> fut2;
+        private InternalFuture<BigInteger> fut2;
 
         /** Auto-inject job context. */
         @IgniteJobContextResource
@@ -116,7 +115,7 @@ public final class ComputeFibonacciContinuationExample {
                         return n == 0 ? BigInteger.ZERO : BigInteger.ONE;
 
                     // Node-local storage.
-                    ClusterNodeLocalMap<Long, IgniteFuture<BigInteger>> locMap 
= g.cluster().nodeLocalMap();
+                    ClusterNodeLocalMap<Long, InternalFuture<BigInteger>> 
locMap = g.cluster().nodeLocalMap();
 
                     // Check if value is cached in node-local-map first.
                     fut1 = locMap.get(n - 1);
@@ -142,8 +141,8 @@ public final class ComputeFibonacciContinuationExample {
 
                     // If futures are not done, then wait asynchronously for 
the result
                     if (!fut1.isDone() || !fut2.isDone()) {
-                        IgniteInClosure<IgniteFuture<BigInteger>> lsnr = new 
IgniteInClosure<IgniteFuture<BigInteger>>() {
-                            @Override public void 
apply(IgniteFuture<BigInteger> f) {
+                        IgniteInClosure<InternalFuture<BigInteger>> lsnr = new 
IgniteInClosure<InternalFuture<BigInteger>>() {
+                            @Override public void 
apply(InternalFuture<BigInteger> f) {
                                 // If both futures are done, resume the 
continuation.
                                 if (fut1.isDone() && fut2.isDone())
                                     // CONTINUATION:

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
index 20e986e..0ede70b 100644
--- 
a/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
+++ 
b/examples/src/main/java/org/gridgain/examples/compute/ComputeRunnableExample.java
@@ -12,7 +12,6 @@ package org.gridgain.examples.compute;
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.examples.*;
-import org.gridgain.grid.*;
 
 import java.util.*;
 
@@ -37,7 +36,7 @@ public class ComputeRunnableExample {
             System.out.println();
             System.out.println("Compute runnable example started.");
 
-            Collection<IgniteFuture> futs = new ArrayList<>();
+            Collection<InternalFuture> futs = new ArrayList<>();
 
             // Enable asynchronous mode.
             IgniteCompute compute = g.compute().enableAsync();
@@ -56,7 +55,7 @@ public class ComputeRunnableExample {
             }
 
             // Wait for all futures to complete.
-            for (IgniteFuture<?> f : futs)
+            for (InternalFuture<?> f : futs)
                 f.get();
 
             System.out.println();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java 
b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
index a30c20f..29db0d9 100644
--- a/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
+++ b/examples/src/main/java/org/gridgain/examples/datagrid/CacheApiExample.java
@@ -11,7 +11,6 @@ package org.gridgain.examples.datagrid;
 
 import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 
 import java.util.concurrent.*;
@@ -72,11 +71,11 @@ public class CacheApiExample {
         cache.putx(2, "2");
 
         // Put asynchronously (every cache operation has async counterpart).
-        IgniteFuture<String> fut = cache.putAsync(3, "3");
+        InternalFuture<String> fut = cache.putAsync(3, "3");
 
         // Asynchronously wait for result.
-        fut.listenAsync(new IgniteInClosure<IgniteFuture<String>>() {
-            @Override public void apply(IgniteFuture<String> fut) {
+        fut.listenAsync(new IgniteInClosure<InternalFuture<String>>() {
+            @Override public void apply(InternalFuture<String> fut) {
                 try {
                     System.out.println("Put operation completed 
[previous-value=" + fut.get() + ']');
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/examples/src/main/scala/org/gridgain/scalar/examples/ScalarContinuationExample.scala
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteScheduler.java 
b/modules/core/src/main/java/org/apache/ignite/IgniteScheduler.java
index 59fe5f7..ce3fa58 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteScheduler.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteScheduler.java
@@ -49,7 +49,7 @@ public interface IgniteScheduler {
      * @see #callLocal(Callable)
      * @see org.apache.ignite.lang.IgniteClosure
      */
-    public IgniteFuture<?> runLocal(@Nullable Runnable r);
+    public InternalFuture<?> runLocal(@Nullable Runnable r);
 
     /**
      * Executes given callable on internal system thread pool asynchronously.
@@ -63,7 +63,7 @@ public interface IgniteScheduler {
      * @see #runLocal(Runnable)
      * @see org.apache.ignite.lang.IgniteOutClosure
      */
-    public <R> IgniteFuture<R> callLocal(@Nullable Callable<R> c);
+    public <R> InternalFuture<R> callLocal(@Nullable Callable<R> c);
 
     /**
      * Schedules job for execution using local <b>cron-based</b> scheduling.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java 
b/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
index c403fd7..725cb6c 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteSystemProperties.java
@@ -9,6 +9,7 @@
 
 package org.apache.ignite;
 
+import org.apache.ignite.lang.*;
 import org.jetbrains.annotations.*;
 
 import javax.net.ssl.*;
@@ -263,10 +264,10 @@ public final class IgniteSystemProperties {
     /**
      * Name of the system property or environment variable to activate 
synchronous
      * listener notification for future objects implemented in GridGain. I.e.
-     * closure passed into method {@link 
org.apache.ignite.lang.IgniteFuture#listenAsync(org.apache.ignite.lang.IgniteInClosure)}
 will
+     * closure passed into method {@link 
InternalFuture#listenAsync(org.apache.ignite.lang.IgniteInClosure)} will
      * be evaluated in the same thread that will end the future.
      *
-     * @see org.apache.ignite.lang.IgniteFuture#syncNotify()
+     * @see InternalFuture#syncNotify()
      */
     public static final String GG_FUT_SYNC_NOTIFICATION = 
"GRIDGAIN_FUTURE_SYNC_NOTIFICATION";
 
@@ -276,7 +277,7 @@ public final class IgniteSystemProperties {
      * upon future completion every listener will be notified concurrently in a
      * separate thread.
      *
-     * @see org.apache.ignite.lang.IgniteFuture#concurrentNotify()
+     * @see InternalFuture#concurrentNotify()
      */
     public static final String GG_FUT_CONCURRENT_NOTIFICATION = 
"GRIDGAIN_FUTURE_CONCURRENT_NOTIFICATION";
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/cluster/ClusterTopologyException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/cluster/ClusterTopologyException.java
 
b/modules/core/src/main/java/org/apache/ignite/cluster/ClusterTopologyException.java
index 879e6bb..baa13ec 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/cluster/ClusterTopologyException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/cluster/ClusterTopologyException.java
@@ -15,7 +15,7 @@ import org.jetbrains.annotations.*;
 /**
  * This exception is used to indicate error with grid topology (e.g., crashed 
node, etc.).
  */
-public class ClusterTopologyException extends IgniteCheckedException {
+public class ClusterTopologyException extends IgniteException {
     /** */
     private static final long serialVersionUID = 0L;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeJob.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeJob.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeJob.java
index 48926c6..8c8038d 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/ComputeJob.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/ComputeJob.java
@@ -67,7 +67,7 @@ import java.util.*;
  *      <ul>
  *      <li>Collision SPI cancelled an active job.</li>
  *      <li>Parent task has completed without waiting for this job's 
result.</li>
- *      <li>User cancelled task by calling {@link ComputeTaskFuture#cancel()} 
method.</li>
+ *      <li>User cancelled task by calling {@link 
InternalComputeTaskFuture#cancel()} method.</li>
  *      </ul>
  * </li>
  * <li>
@@ -137,7 +137,7 @@ public interface ComputeJob extends Serializable {
      * This method is called when system detects that completion of this
      * job can no longer alter the overall outcome (for example, when parent 
task
      * has already reduced the results). Job is also cancelled when
-     * {@link ComputeTaskFuture#cancel()} is called.
+     * {@link InternalComputeTaskFuture#cancel()} is called.
      * <p>
      * Note that job cancellation is only a hint, and just like with
      * {@link Thread#interrupt()}  method, it is really up to the actual job

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeJobResult.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeJobResult.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeJobResult.java
index 7c9ae3e..1581f55 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/ComputeJobResult.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/ComputeJobResult.java
@@ -86,7 +86,7 @@ public interface ComputeJobResult {
      * execution result even if the job was canceled.
      * <p>
      * Job can receive cancellation request if the task was explicitly 
cancelled
-     * from future (see {@link ComputeTaskFuture#cancel()}) or if task 
completed prior
+     * from future (see {@link InternalComputeTaskFuture#cancel()}) or if task 
completed prior
      * to getting results from all remote jobs.
      *
      * @return {@code true} if job received cancellation request and {@code 
false} otherwise.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeTask.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTask.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTask.java
index b3d90f3..de72aa8 100644
--- a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTask.java
+++ b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTask.java
@@ -96,7 +96,7 @@ import java.util.*;
  *      method returned {@link ComputeJobResultPolicy#REDUCE} policy, method 
{@link #reduce(List) reduce(List)}
  *      is called to aggregate received results into one final result. Once 
this method is finished the
  *      execution of the grid task is complete. This result will be returned 
to the user through
- *      {@link ComputeTaskFuture#get()} method.
+ *      {@link InternalComputeTaskFuture#get()} method.
  * </li>
  * </ol>
  * <p>
@@ -240,7 +240,7 @@ public interface ComputeTask<T, R> extends Serializable {
      * @return Map of grid jobs assigned to subgrid node. Unless {@link 
ComputeTaskContinuousMapper} is
      *      injected into task, if {@code null} or empty map is returned, 
exception will be thrown.
      * @throws IgniteCheckedException If mapping could not complete 
successfully. This exception will be
-     *      thrown out of {@link ComputeTaskFuture#get()} method.
+     *      thrown out of {@link InternalComputeTaskFuture#get()} method.
      */
     @Nullable public Map<? extends ComputeJob, ClusterNode> 
map(List<ClusterNode> subgrid, @Nullable T arg) throws IgniteCheckedException;
 
@@ -257,13 +257,13 @@ public interface ComputeTask<T, R> extends Serializable {
      * @return Result policy that dictates how to process further upcoming
      *       job results.
      * @throws IgniteCheckedException If handling a job result caused an 
error. This exception will
-     *      be thrown out of {@link ComputeTaskFuture#get()} method.
+     *      be thrown out of {@link InternalComputeTaskFuture#get()} method.
      */
     public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> rcvd) throws IgniteCheckedException;
 
     /**
      * Reduces (or aggregates) results received so far into one compound 
result to be returned to
-     * caller via {@link ComputeTaskFuture#get()} method.
+     * caller via {@link InternalComputeTaskFuture#get()} method.
      * <p>
      * Note, that if some jobs did not succeed and could not be failed over 
then the list of
      * results passed into this method will include the failed results. 
Otherwise, failed
@@ -273,7 +273,7 @@ public interface ComputeTask<T, R> extends Serializable {
      *      {@link ComputeTaskNoResultCache} annotation, then this list will 
be empty.
      * @return Grid job result constructed from results of remote executions.
      * @throws IgniteCheckedException If reduction or results caused an error. 
This exception will
-     *      be thrown out of {@link ComputeTaskFuture#get()} method.
+     *      be thrown out of {@link InternalComputeTaskFuture#get()} method.
      */
     @Nullable public R reduce(List<ComputeJobResult> results) throws 
IgniteCheckedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskAdapter.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskAdapter.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskAdapter.java
index bcb3715..74ce7a0 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskAdapter.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskAdapter.java
@@ -11,7 +11,6 @@ package org.apache.ignite.compute;
 
 import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.*;
 
 import java.util.*;
 
@@ -78,7 +77,7 @@ public abstract class ComputeTaskAdapter<T, R> implements 
ComputeTask<T, R> {
      * @return Result policy that dictates how to process further upcoming
      *       job results.
      * @throws IgniteCheckedException If handling a job result caused an error 
effectively rejecting
-     *      a failover. This exception will be thrown out of {@link 
ComputeTaskFuture#get()} method.
+     *      a failover. This exception will be thrown out of {@link 
InternalComputeTaskFuture#get()} method.
      */
     @Override public ComputeJobResultPolicy result(ComputeJobResult res, 
List<ComputeJobResult> rcvd) throws IgniteCheckedException {
         IgniteCheckedException e = res.getException();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskFuture.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskFuture.java
index 70d4934..aa3fc2a 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskFuture.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskFuture.java
@@ -27,21 +27,21 @@ public interface ComputeTaskFuture<R> extends 
IgniteFuture<R> {
      *
      * @throws ComputeTaskTimeoutException If task execution timed out.
      */
-    @Override public R get() throws IgniteCheckedException;
+    @Override public R get() throws IgniteException;
 
     /**
      * {@inheritDoc}
      *
      * @throws ComputeTaskTimeoutException If task execution timed out.
      */
-    @Override public R get(long timeout) throws IgniteCheckedException;
+    @Override public R get(long timeout) throws IgniteException;
 
     /**
      * {@inheritDoc}
      *
      * @throws ComputeTaskTimeoutException If task execution timed out.
      */
-    @Override public R get(long timeout, TimeUnit unit) throws 
IgniteCheckedException;
+    @Override public R get(long timeout, TimeUnit unit) throws IgniteException;
 
     /**
      * Gets task session of execution grid task.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
index 9ac37ff..83341b5 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskSession.java
@@ -431,5 +431,5 @@ public interface ComputeTaskSession {
      *
      * @return Future that will be completed when task "<tt>map</tt>" step has 
completed.
      */
-    public IgniteFuture<?> mapFuture();
+    public InternalFuture<?> mapFuture();
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
index e2690be..a638091 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/ComputeTaskTimeoutException.java
@@ -14,7 +14,7 @@ import org.jetbrains.annotations.*;
 
 /**
  * This exception indicates that task execution timed out. It is thrown from
- * {@link ComputeTaskFuture#get()} method.
+ * {@link InternalComputeTaskFuture#get()} method.
  */
 public class ComputeTaskTimeoutException extends IgniteCheckedException {
     /** */

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/compute/InternalComputeTaskFuture.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/compute/InternalComputeTaskFuture.java
 
b/modules/core/src/main/java/org/apache/ignite/compute/InternalComputeTaskFuture.java
new file mode 100644
index 0000000..ccbdd42
--- /dev/null
+++ 
b/modules/core/src/main/java/org/apache/ignite/compute/InternalComputeTaskFuture.java
@@ -0,0 +1,52 @@
+/* @java.file.header */
+
+/*  _________        _____ __________________        _____
+ *  __  ____/___________(_)______  /__  ____/______ ____(_)_______
+ *  _  / __  __  ___/__  / _  __  / _  / __  _  __ `/__  / __  __ \
+ *  / /_/ /  _  /    _  /  / /_/ /  / /_/ /  / /_/ / _  /  _  / / /
+ *  \____/   /_/     /_/   \_,__/   \____/   \__,_/  /_/   /_/ /_/
+ */
+
+package org.apache.ignite.compute;
+
+import org.apache.ignite.*;
+import org.apache.ignite.lang.*;
+
+import java.util.*;
+import java.util.concurrent.*;
+
+/**
+ * This class defines a handler for asynchronous task execution. It's similar 
in design
+ * to standard JDK {@link Future} interface but has improved and easier to use 
exception
+ * hierarchy.
+ * @param <R> Type of the task result returning from {@link 
ComputeTask#reduce(List)} method.
+ */
+public interface InternalComputeTaskFuture<R> extends InternalFuture<R> {
+    /**
+     * {@inheritDoc}
+     *
+     * @throws ComputeTaskTimeoutException If task execution timed out.
+     */
+    @Override public R get() throws IgniteCheckedException;
+
+    /**
+     * {@inheritDoc}
+     *
+     * @throws ComputeTaskTimeoutException If task execution timed out.
+     */
+    @Override public R get(long timeout) throws IgniteCheckedException;
+
+    /**
+     * {@inheritDoc}
+     *
+     * @throws ComputeTaskTimeoutException If task execution timed out.
+     */
+    @Override public R get(long timeout, TimeUnit unit) throws 
IgniteCheckedException;
+
+    /**
+     * Gets task session of execution grid task.
+     *
+     * @return Task session.
+     */
+    public ComputeTaskSession getTaskSession();
+}

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
----------------------------------------------------------------------
diff --git 
a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java 
b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
index 8fdc30c..ab75589 100644
--- a/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
+++ b/modules/core/src/main/java/org/apache/ignite/fs/mapreduce/IgniteFsJob.java
@@ -10,8 +10,8 @@
 package org.apache.ignite.fs.mapreduce;
 
 import org.apache.ignite.*;
+import org.apache.ignite.compute.*;
 import org.apache.ignite.fs.*;
-import org.gridgain.grid.*;
 
 import java.io.*;
 
@@ -52,7 +52,7 @@ public interface IgniteFsJob {
      * This method is called when system detects that completion of this
      * job can no longer alter the overall outcome (for example, when parent 
task
      * has already reduced the results). Job is also cancelled when
-     * {@link org.apache.ignite.compute.ComputeTaskFuture#cancel()} is called.
+     * {@link InternalComputeTaskFuture#cancel()} is called.
      * <p>
      * Note that job cancellation is only a hint, and just like with
      * {@link Thread#interrupt()}  method, it is really up to the actual job

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
----------------------------------------------------------------------
diff --git 
a/examples/src/main/scala/org/gridgain/scalar/examples/ScalarContinuationExample.scala
 
b/examples/src/main/scala/org/gridgain/scalar/examples/ScalarContinuationExample.scala
index 7e8fb1b..f710d9c 100644
--- 
a/examples/src/main/scala/org/gridgain/scalar/examples/ScalarContinuationExample.scala
+++ 
b/examples/src/main/scala/org/gridgain/scalar/examples/ScalarContinuationExample.scala
@@ -11,7 +11,7 @@
 package org.gridgain.scalar.examples
 
 import org.apache.ignite.compute.ComputeJobContext
-import org.apache.ignite.lang.{IgniteFuture, IgniteClosure}
+import org.apache.ignite.lang.{InternalFuture, IgniteClosure}
 import org.apache.ignite.resources.IgniteJobContextResource
 import org.gridgain.scalar._
 import scalar._
@@ -73,7 +73,7 @@ class FibonacciClosure (
     // However, these fields will be preserved locally while
     // this closure is being "held", i.e. while it is suspended
     // and is waiting to be continued.
-    @transient private var fut1, fut2: IgniteFuture[BigInteger] = null
+    @transient private var fut1, fut2: InternalFuture[BigInteger] = null
 
     // Auto-inject job context.
     @IgniteJobContextResource
@@ -95,7 +95,7 @@ class FibonacciClosure (
                     BigInteger.ONE
 
             // Get properly typed node-local storage.
-            val store = g.cluster().nodeLocalMap[Long, 
IgniteFuture[BigInteger]]()
+            val store = g.cluster().nodeLocalMap[Long, 
InternalFuture[BigInteger]]()
 
             // Check if value is cached in node-local store first.
             fut1 = store.get(n - 1)
@@ -125,7 +125,7 @@ class FibonacciClosure (
 
             // If futures are not done, then wait asynchronously for the result
             if (!fut1.isDone || !fut2.isDone) {
-                val lsnr = (fut: IgniteFuture[BigInteger]) => {
+                val lsnr = (fut: InternalFuture[BigInteger]) => {
                     // This method will be called twice, once for each future.
                     // On the second call - we have to have both futures to be 
done
                     // - therefore we can call the continuation.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
----------------------------------------------------------------------
diff --git 
a/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
 
b/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
index 0266d3a..e646cd0 100644
--- 
a/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
+++ 
b/modules/aop/src/test/java/org/gridgain/loadtests/direct/singlesplit/GridSingleSplitsLoadTest.java
@@ -14,7 +14,6 @@ import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.logger.log4j.*;
 import org.apache.log4j.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.loadtest.*;
 import org.apache.ignite.spi.communication.tcp.*;
 import org.apache.ignite.spi.discovery.tcp.*;
@@ -102,7 +101,7 @@ public class GridSingleSplitsLoadTest extends 
GridCommonAbstractTest {
 
                         comp.execute(new GridSingleSplitTestTask(), levels);
 
-                        ComputeTaskFuture<Integer> fut = comp.future();
+                        InternalComputeTaskFuture<Integer> fut = comp.future();
 
                         int res = fut.get();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/aws/src/main/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpi.java
----------------------------------------------------------------------
diff --git 
a/modules/aws/src/main/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpi.java
 
b/modules/aws/src/main/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpi.java
index 316e014..84b07ba 100644
--- 
a/modules/aws/src/main/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpi.java
+++ 
b/modules/aws/src/main/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpi.java
@@ -274,7 +274,7 @@ public class GridS3CheckpointSpi extends IgniteSpiAdapter 
implements CheckpointS
                     try {
                         U.sleep(200);
                     }
-                    catch (GridInterruptedException e) {
+                    catch (InternalInterruptedException e) {
                         throw new IgniteSpiException("Thread has been 
interrupted.", e);
                     }
             }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/aws/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/s3/GridTcpDiscoveryS3IpFinder.java
----------------------------------------------------------------------
diff --git 
a/modules/aws/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/s3/GridTcpDiscoveryS3IpFinder.java
 
b/modules/aws/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/s3/GridTcpDiscoveryS3IpFinder.java
index 0eb38f1..ddb8869 100644
--- 
a/modules/aws/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/s3/GridTcpDiscoveryS3IpFinder.java
+++ 
b/modules/aws/src/main/java/org/apache/ignite/spi/discovery/tcp/ipfinder/s3/GridTcpDiscoveryS3IpFinder.java
@@ -242,7 +242,7 @@ public class GridTcpDiscoveryS3IpFinder extends 
TcpDiscoveryIpFinderAdapter {
                             try {
                                 U.sleep(200);
                             }
-                            catch (GridInterruptedException e) {
+                            catch (InternalInterruptedException e) {
                                 throw new IgniteSpiException("Thread has been 
interrupted.", e);
                             }
                     }
@@ -262,7 +262,7 @@ public class GridTcpDiscoveryS3IpFinder extends 
TcpDiscoveryIpFinderAdapter {
             try {
                 U.await(initLatch);
             }
-            catch (GridInterruptedException e) {
+            catch (InternalInterruptedException e) {
                 throw new IgniteSpiException("Thread has been interrupted.", 
e);
             }
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/aws/src/test/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpiSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/aws/src/test/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpiSelfTest.java
 
b/modules/aws/src/test/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpiSelfTest.java
index f31919f..972ef72 100644
--- 
a/modules/aws/src/test/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpiSelfTest.java
+++ 
b/modules/aws/src/test/java/org/apache/ignite/spi/checkpoint/s3/GridS3CheckpointSpiSelfTest.java
@@ -199,9 +199,9 @@ public class GridS3CheckpointSpiSelfTest extends 
GridSpiAbstractTest<GridS3Check
      * Wrapper around {@link 
GridTestUtils#retryAssert(org.apache.ignite.IgniteLogger, int, long, 
GridAbsClosure)}.
      * Provides s3-specific timeouts.
      * @param assertion Closure with assertion inside.
-     * @throws GridInterruptedException If was interrupted.
+     * @throws InternalInterruptedException If was interrupted.
      */
-    private void assertWithRetries(GridAbsClosureX assertion) throws 
GridInterruptedException {
+    private void assertWithRetries(GridAbsClosureX assertion) throws 
InternalInterruptedException {
         GridTestUtils.retryAssert(log, 6, 5000, assertion);
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/clients/src/test/java/org/gridgain/client/GridClientAbstractMultiThreadedSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/clients/src/test/java/org/gridgain/client/GridClientAbstractMultiThreadedSelfTest.java
 
b/modules/clients/src/test/java/org/gridgain/client/GridClientAbstractMultiThreadedSelfTest.java
index 306764e..7ccef60 100644
--- 
a/modules/clients/src/test/java/org/gridgain/client/GridClientAbstractMultiThreadedSelfTest.java
+++ 
b/modules/clients/src/test/java/org/gridgain/client/GridClientAbstractMultiThreadedSelfTest.java
@@ -18,7 +18,6 @@ import org.apache.ignite.resources.*;
 import org.gridgain.client.balancer.*;
 import org.gridgain.client.impl.*;
 import org.gridgain.client.ssl.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.affinity.*;
 import org.gridgain.grid.kernal.*;
@@ -298,7 +297,7 @@ public abstract class 
GridClientAbstractMultiThreadedSelfTest extends GridCommon
 
             final String val = "v" + i;
 
-            IgniteFuture<?> f = multithreadedAsync(new Callable<Object>() {
+            InternalFuture<?> f = multithreadedAsync(new Callable<Object>() {
                 @Override public Object call() throws Exception {
                     l.await();
 
@@ -326,7 +325,7 @@ public abstract class 
GridClientAbstractMultiThreadedSelfTest extends GridCommon
 
         final ConcurrentLinkedQueue<String> execQueue = new 
ConcurrentLinkedQueue<>();
 
-        IgniteFuture<?> fut = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut = multithreadedAsync(new Runnable() {
             @Override
             public void run() {
                 long processed;
@@ -405,7 +404,7 @@ public abstract class 
GridClientAbstractMultiThreadedSelfTest extends GridCommon
 
         assertEquals(NODES_CNT, client.compute().refreshTopology(false, 
false).size());
 
-        IgniteFuture<?> fut = multithreadedAsync(new Runnable() {
+        InternalFuture<?> fut = multithreadedAsync(new Runnable() {
             @SuppressWarnings("OverlyStrongTypeCast")
             @Override public void run() {
                 try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/clients/src/test/java/org/gridgain/client/GridClientStartNodeTask.java
----------------------------------------------------------------------
diff --git 
a/modules/clients/src/test/java/org/gridgain/client/GridClientStartNodeTask.java
 
b/modules/clients/src/test/java/org/gridgain/client/GridClientStartNodeTask.java
index ada470e..3d56a10 100644
--- 
a/modules/clients/src/test/java/org/gridgain/client/GridClientStartNodeTask.java
+++ 
b/modules/clients/src/test/java/org/gridgain/client/GridClientStartNodeTask.java
@@ -13,7 +13,6 @@ import org.apache.ignite.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.configuration.*;
 import org.apache.ignite.resources.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
 import org.springframework.beans.factory.*;
@@ -142,7 +141,7 @@ public class GridClientStartNodeTask extends 
GridTaskSingleJobSplitAdapter<Strin
      * @throws IgniteCheckedException On any exception.
      */
     private static void changeTopology(Ignite parent, int add, int rmv, String 
type) throws IgniteCheckedException {
-        Collection<ComputeTaskFuture<?>> tasks = new ArrayList<>();
+        Collection<InternalComputeTaskFuture<?>> tasks = new ArrayList<>();
 
         IgniteCompute comp = parent.compute().enableAsync();
 
@@ -153,7 +152,7 @@ public class GridClientStartNodeTask extends 
GridTaskSingleJobSplitAdapter<Strin
             tasks.add(comp.future());
         }
 
-        for (ComputeTaskFuture<?> task : tasks)
+        for (InternalComputeTaskFuture<?> task : tasks)
             task.get();
 
         // Stop nodes in sequence.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorStartSelfTest.java
----------------------------------------------------------------------
diff --git 
a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorStartSelfTest.java
 
b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorStartSelfTest.java
index 22eaac7..5596053 100644
--- 
a/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorStartSelfTest.java
+++ 
b/modules/clients/src/test/java/org/gridgain/grid/kernal/processors/rest/GridRestProcessorStartSelfTest.java
@@ -111,7 +111,7 @@ public class GridRestProcessorStartSelfTest extends 
GridCommonAbstractTest {
         try {
             gridReady.await();
 
-            IgniteFuture<GridClient> c = GridTestUtils.runAsync(new 
Callable<GridClient>() {
+            InternalFuture<GridClient> c = GridTestUtils.runAsync(new 
Callable<GridClient>() {
                 @Override public GridClient call() throws Exception {
                     return GridClientFactory.start(cfg);
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java 
b/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
index 613a521..2b8dd7a 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteCompute.java
@@ -12,7 +12,6 @@ package org.apache.ignite;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.compute.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -114,9 +113,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job which will be co-located on the node with given affinity 
key.
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
      * @throws IgniteCheckedException If job failed.
      */
-    public void affinityRun(@Nullable String cacheName, Object affKey, 
Runnable job) throws IgniteCheckedException;
+    public void affinityRun(@Nullable String cacheName, Object affKey, 
Runnable job) throws IgniteException;
 
     /**
      * Executes given job on the node where data for provided affinity key is 
located
@@ -128,11 +127,11 @@ public interface IgniteCompute extends IgniteAsyncSupport 
{
      * @param affKey Affinity key.
      * @param job Job which will be co-located on the node with given affinity 
key.
      * @return Job result.
      * @throws IgniteCheckedException If job failed.
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
      */
-    public <R> R affinityCall(@Nullable String cacheName, Object affKey, 
Callable<R> job) throws IgniteCheckedException;
+    public <R> R affinityCall(@Nullable String cacheName, Object affKey, 
Callable<R> job) throws IgniteException;
 
     /**
      * Executes given task on the grid projection. For step-by-step 
explanation of task execution process
@@ -145,9 +144,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *      class name is used as task name.
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
      * @throws IgniteCheckedException If task failed.
      */
-    public <T, R> R execute(Class<? extends ComputeTask<T, R>> taskCls, 
@Nullable T arg) throws IgniteCheckedException;
+    public <T, R> R execute(Class<? extends ComputeTask<T, R>> taskCls, 
@Nullable T arg) throws IgniteException;
 
     /**
      * Executes given task on this grid projection. For step-by-step 
explanation of task execution process
@@ -160,9 +159,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *      class name is used as task name.
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
      * @throws IgniteCheckedException If task failed.
      */
-    public <T, R> R execute(ComputeTask<T, R> task, @Nullable T arg) throws 
IgniteCheckedException;
+    public <T, R> R execute(ComputeTask<T, R> task, @Nullable T arg) throws 
IgniteException;
 
     /**
      * Executes given task on this grid projection. For step-by-step 
explanation of task execution process
@@ -176,10 +175,10 @@ public interface IgniteCompute extends IgniteAsyncSupport 
{
      * @param taskName Name of the task to execute.
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
      * @throws IgniteCheckedException If task failed.
      * @see org.apache.ignite.compute.ComputeTask for information about task 
execution.
      */
-    public <T, R> R execute(String taskName, @Nullable T arg) throws 
IgniteCheckedException;
+    public <T, R> R execute(String taskName, @Nullable T arg) throws 
IgniteException;
 
     /**
      * Broadcasts given job to all nodes in grid projection.
@@ -187,9 +186,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * Supports asynchronous execution (see {@link IgniteAsyncSupport}).
      *
      * @param job Job to broadcast to all projection nodes.
      * @throws IgniteCheckedException If job failed.
      */
-    public void broadcast(Runnable job) throws IgniteCheckedException;
+    public void broadcast(Runnable job) throws IgniteException;
 
     /**
      * Broadcasts given job to all nodes in grid projection. Every 
participating node will return a
@@ -199,9 +198,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job to broadcast to all projection nodes.
      * @return Collection of results for this execution.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <R> Collection<R> broadcast(Callable<R> job) throws 
IgniteCheckedException;
+    public <R> Collection<R> broadcast(Callable<R> job) throws IgniteException;
 
     /**
      * Broadcasts given closure job with passed in argument to all nodes in 
grid projection.
@@ -213,9 +212,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to broadcast to all projection nodes.
      * @param arg Job closure argument.
      * @return Collection of results for this execution.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <R, T> Collection<R> broadcast(IgniteClosure<T, R> job, @Nullable T 
arg) throws IgniteCheckedException;
+    public <R, T> Collection<R> broadcast(IgniteClosure<T, R> job, @Nullable T 
arg) throws IgniteException;
 
     /**
      * Executes provided job on a node in this grid projection.
@@ -223,9 +222,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * Supports asynchronous execution (see {@link IgniteAsyncSupport}).
      *
      * @param job Job closure to execute.
      * @throws IgniteCheckedException If execution failed.
      */
-    public void run(Runnable job) throws IgniteCheckedException;
+    public void run(Runnable job) throws IgniteException;
 
     /**
      * Executes collection of jobs on grid nodes within this grid projection.
@@ -233,9 +232,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * Supports asynchronous execution (see {@link IgniteAsyncSupport}).
      *
      * @param jobs Collection of jobs to execute.
      * @throws IgniteCheckedException If execution failed.
      */
-    public void run(Collection<? extends Runnable> jobs) throws 
IgniteCheckedException;
+    public void run(Collection<? extends Runnable> jobs) throws 
IgniteException;
 
     /**
      * Executes provided job on a node in this grid projection. The result of 
the
@@ -245,9 +244,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job to execute.
      * @return Job result.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <R> R call(Callable<R> job) throws IgniteCheckedException;
+    public <R> R call(Callable<R> job) throws IgniteException;
 
     /**
      * Executes collection of jobs on nodes within this grid projection.
@@ -257,9 +256,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param jobs Collection of jobs to execute.
      * @return Collection of job results for this execution.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <R> Collection<R> call(Collection<? extends Callable<R>> jobs) 
throws IgniteCheckedException;
+    public <R> Collection<R> call(Collection<? extends Callable<R>> jobs) 
throws IgniteException;
 
     /**
      * Executes collection of jobs on nodes within this grid projection. The 
returned
@@ -270,9 +269,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param jobs Collection of jobs to execute.
      * @param rdc Reducer to reduce all job results into one individual return 
value.
      * @return Future with reduced job result for this execution.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <R1, R2> R2 call(Collection<? extends Callable<R1>> jobs, 
IgniteReducer<R1, R2> rdc) throws IgniteCheckedException;
+    public <R1, R2> R2 call(Collection<? extends Callable<R1>> jobs, 
IgniteReducer<R1, R2> rdc) throws IgniteException;
 
     /**
      * Executes provided closure job on a node in this grid projection. This 
method is different
@@ -284,9 +283,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to run.
      * @param arg Job argument.
      * @return Job result.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <R, T> R apply(IgniteClosure<T, R> job, @Nullable T arg) throws 
IgniteCheckedException;
+    public <R, T> R apply(IgniteClosure<T, R> job, @Nullable T arg) throws 
IgniteException;
 
     /**
      * Executes provided closure job on nodes within this grid projection. A 
new job is executed for
@@ -298,9 +297,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to run.
      * @param args Job arguments.
      * @return Collection of job results.
      * @throws IgniteCheckedException If execution failed.
      */
-    public <T, R> Collection<R> apply(IgniteClosure<T, R> job, Collection<? 
extends T> args) throws IgniteCheckedException;
+    public <T, R> Collection<R> apply(IgniteClosure<T, R> job, Collection<? 
extends T> args) throws IgniteException;
 
     /**
      * Executes provided closure job on nodes within this grid projection. A 
new job is executed for
@@ -314,17 +313,17 @@ public interface IgniteCompute extends IgniteAsyncSupport 
{
      * @param args Job arguments.
      * @param rdc Reducer to reduce all job results into one individual return 
value.
      * @return Future with reduced job result for this execution.
      * @throws IgniteCheckedException If execution failed.
      */
     public <R1, R2, T> R2 apply(IgniteClosure<T, R1> job, Collection<? extends 
T> args,
-        IgniteReducer<R1, R2> rdc) throws IgniteCheckedException;
+        IgniteReducer<R1, R2> rdc) throws IgniteException;
 
     /**
      * Gets tasks future for active tasks started on local node.
      *
      * @return Map of active tasks keyed by their task task session ID.
      */
-    public <R> Map<IgniteUuid, ComputeTaskFuture<R>> activeTaskFutures();
+    public <R> Map<IgniteUuid, InternalComputeTaskFuture<R>> 
activeTaskFutures();
 
     /**
      * Sets task name for the next executed task on this projection in the 
<b>current thread</b>.
@@ -396,9 +395,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *      class name will be used as task's name.
      * @param clsLdr Task class loader. This class loader is in charge
      *      of loading all necessary resources for task execution.
-     * @throws IgniteCheckedException If task is invalid and cannot be 
deployed.
+     * @throws IgniteException If task is invalid and cannot be deployed.
      */
-    public void localDeployTask(Class<? extends ComputeTask> taskCls, 
ClassLoader clsLdr) throws IgniteCheckedException;
+    public void localDeployTask(Class<? extends ComputeTask> taskCls, 
ClassLoader clsLdr) throws IgniteException;
 
     /**
      * Gets map of all locally deployed tasks keyed by their task name .
@@ -413,9 +412,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * undeployed on every node.
      *
      * @param taskName Name of the task to undeploy.
      * @throws IgniteCheckedException Thrown if undeploy failed.
      */
-    public void undeployTask(String taskName) throws IgniteCheckedException;
+    public void undeployTask(String taskName) throws IgniteException;
 
     /** {@inheritDoc} */
     @Override public <R> ComputeTaskFuture<R> future();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
----------------------------------------------------------------------
@@ -114,9 +113,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
-     * @throws IgniteCheckedException If job failed.
+     * @throws IgniteException If job failed.
      */
@@ -128,11 +127,11 @@ public interface IgniteCompute extends IgniteAsyncSupport 
key.
      * @return Job result.
-     * @throws IgniteCheckedException If job failed.
+     * @throws IgniteException If job failed.
      * @see org.apache.ignite.compute.ComputeJobContext#cacheName()
      * @see org.apache.ignite.compute.ComputeJobContext#affinityKey()
@@ -145,9 +144,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
-     * @throws IgniteCheckedException If task failed.
+     * @throws IgniteException If task failed.
      */
@@ -160,9 +159,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
-     * @throws IgniteCheckedException If task failed.
+     * @throws IgniteException If task failed.
      */
@@ -176,10 +175,10 @@ public interface IgniteCompute extends IgniteAsyncSupport 
      * @param arg Optional argument of task execution, can be {@code null}.
      * @return Task result.
-     * @throws IgniteCheckedException If task failed.
+     * @throws IgniteException If task failed.
      * @see org.apache.ignite.compute.ComputeTask for information about task 
execution.
@@ -187,9 +186,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job to broadcast to all projection nodes.
-     * @throws IgniteCheckedException If job failed.
+     * @throws IgniteException If job failed.
      */
@@ -199,9 +198,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to broadcast to all projection nodes.
      * @return Collection of results for this execution.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -213,9 +212,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Job closure argument.
      * @return Collection of results for this execution.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -223,9 +222,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param job Job closure to execute.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -233,9 +232,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param jobs Collection of jobs to execute.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -245,9 +244,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param job Job to execute.
      * @return Job result.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -257,9 +256,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param jobs Collection of jobs to execute.
      * @return Collection of job results for this execution.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -270,9 +269,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
value.
      * @return Future with reduced job result for this execution.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -284,9 +283,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param arg Job argument.
      * @return Job result.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -298,9 +297,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      * @param args Job arguments.
      * @return Collection of job results.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
@@ -314,17 +313,17 @@ public interface IgniteCompute extends IgniteAsyncSupport 
value.
      * @return Future with reduced job result for this execution.
-     * @throws IgniteCheckedException If execution failed.
+     * @throws IgniteException If execution failed.
      */
     public <R1, R2, T> R2 apply(IgniteClosure<T, R1> job, Collection<? extends 
@@ -413,9 +412,9 @@ public interface IgniteCompute extends IgniteAsyncSupport {
      *
      * @param taskName Name of the task to undeploy.
-     * @throws IgniteCheckedException Thrown if undeploy failed.
+     * @throws IgniteException Thrown if undeploy failed.
      */
diff --git a/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java 
b/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
index ecedb0f..fe54128 100644
--- a/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
+++ b/modules/core/src/main/java/org/apache/ignite/IgniteDataLoader.java
@@ -187,7 +187,7 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      *
      * @return Future for this loading process.
      */
-    public IgniteFuture<?> future();
+    public InternalFuture<?> future();
 
     /**
      * Optional deploy class for peer deployment. All classes loaded by a data 
loader
@@ -214,11 +214,11 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      * @param key Key.
      * @return Future fo this operation.
      * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      */
-    public IgniteFuture<?> removeData(K key)  throws IgniteCheckedException, 
GridInterruptedException, IllegalStateException;
+    public InternalFuture<?> removeData(K key)  throws IgniteCheckedException, 
InternalInterruptedException, IllegalStateException;
 
     /**
      * Adds data for loading on remote node. This method can be called from 
multiple
@@ -232,11 +232,11 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      * @param val Value or {@code null} if respective entry must be removed 
from cache.
      * @return Future fo this operation.
      * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      */
-    public IgniteFuture<?> addData(K key, @Nullable V val) throws 
IgniteCheckedException, GridInterruptedException,
+    public InternalFuture<?> addData(K key, @Nullable V val) throws 
IgniteCheckedException, InternalInterruptedException,
         IllegalStateException;
 
     /**
@@ -250,11 +250,11 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      * @param entry Entry.
      * @return Future fo this operation.
      * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      */
-    public IgniteFuture<?> addData(Map.Entry<K, V> entry) throws 
IgniteCheckedException, GridInterruptedException,
+    public InternalFuture<?> addData(Map.Entry<K, V> entry) throws 
IgniteCheckedException, InternalInterruptedException,
         IllegalStateException;
 
     /**
@@ -270,7 +270,7 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      *      {@link #close(boolean)} has already been called on loader.
      * @return Future for this load operation.
      */
-    public IgniteFuture<?> addData(Collection<? extends Map.Entry<K, V>> 
entries) throws IllegalStateException;
+    public InternalFuture<?> addData(Collection<? extends Map.Entry<K, V>> 
entries) throws IllegalStateException;
 
     /**
      * Adds data for loading on remote node. This method can be called from 
multiple
@@ -285,7 +285,7 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      *      {@link #close(boolean)} has already been called on loader.
      * @return Future for this load operation.
      */
-    public IgniteFuture<?> addData(Map<K, V> entries) throws 
IllegalStateException;
+    public InternalFuture<?> addData(Map<K, V> entries) throws 
IllegalStateException;
 
     /**
      * Loads any remaining data, but doesn't close the loader. Data can be 
still added after
@@ -297,33 +297,33 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      * use {@link #tryFlush()} method.
      *
      * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      * @see #tryFlush()
      */
-    public void flush() throws IgniteCheckedException, 
GridInterruptedException, IllegalStateException;
+    public void flush() throws IgniteCheckedException, 
InternalInterruptedException, IllegalStateException;
 
     /**
      * Makes an attempt to load remaining data. This method is mostly similar 
to {@link #flush},
      * with the difference that it won't wait and will exit immediately.
      *
      * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
      * @see #flush()
      */
-    public void tryFlush() throws IgniteCheckedException, 
GridInterruptedException, IllegalStateException;
+    public void tryFlush() throws IgniteCheckedException, 
InternalInterruptedException, IllegalStateException;
 
     /**
      * Loads any remaining data and closes this loader.
      *
      * @param cancel {@code True} to cancel ongoing loading operations.
      * @throws IgniteCheckedException If failed to map key to node.
      * @throws GridInterruptedException If thread has been interrupted.
      */
-    public void close(boolean cancel) throws IgniteCheckedException, 
GridInterruptedException;
+    public void close(boolean cancel) throws IgniteCheckedException, 
InternalInterruptedException;
 
     /**
      * Closes data loader. This method is identical to calling {@link 
#close(boolean) close(false)} method.
@@ -332,7 +332,7 @@ public interface IgniteDataLoader<K, V> extends 
AutoCloseable {
      * {@code try-with-resources} statement.
      *
      * @throws IgniteCheckedException If failed to close data loader.
      * @throws GridInterruptedException If thread has been interrupted.
      */
-    @Override public void close() throws IgniteCheckedException, 
GridInterruptedException;
+    @Override public void close() throws IgniteCheckedException, 
InternalInterruptedException;
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/90948e67/modules/core/src/main/java/org/apache/ignite/IgniteScheduler.java
----------------------------------------------------------------------
@@ -214,11 +214,11 @@ public interface IgniteDataLoader<K, V> extends 
      * @return Future fo this operation.
      * @throws IgniteCheckedException If failed to map key to node.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
@@ -232,11 +232,11 @@ public interface IgniteDataLoader<K, V> extends 
      * @return Future fo this operation.
      * @throws IgniteCheckedException If failed to map key to node.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
@@ -250,11 +250,11 @@ public interface IgniteDataLoader<K, V> extends 
      * @return Future fo this operation.
      * @throws IgniteCheckedException If failed to map key to node.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
@@ -297,33 +297,33 @@ public interface IgniteDataLoader<K, V> extends 
      *
      * @throws IgniteCheckedException If failed to map key to node.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
@@ -297,33 +297,33 @@ public interface IgniteDataLoader<K, V> extends 
      *
      * @throws IgniteCheckedException If failed to map key to node.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      * @throws IllegalStateException If grid has been concurrently stopped or
      *      {@link #close(boolean)} has already been called on loader.
@@ -297,33 +297,33 @@ public interface IgniteDataLoader<K, V> extends 
      * @param cancel {@code True} to cancel ongoing loading operations.
      * @throws IgniteCheckedException If failed to map key to node.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      */
@@ -332,7 +332,7 @@ public interface IgniteDataLoader<K, V> extends 
      *
      * @throws IgniteCheckedException If failed to close data loader.
-     * @throws GridInterruptedException If thread has been interrupted.
+     * @throws InternalInterruptedException If thread has been interrupted.
      */
diff --git 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
index fe55b87..7188085 100644
--- 
a/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
+++ 
b/modules/core/src/main/java/org/apache/ignite/lang/IgniteAsyncSupportAdapter.java
@@ -62,9 +62,9 @@ public class IgniteAsyncSupportAdapter implements 
IgniteAsyncSupport {
      * @param fut Future.
      * @return If async mode is enabled saves future and returns {@code null},
      *         otherwise waits for future and returns result.
-     * @throws IgniteCheckedException If asynchronous mode is disabled and 
future failed.
+     * @throws IgniteException If asynchronous mode is disabled and future 
failed.
      */
-    public <R> R saveOrGet(IgniteFuture<R> fut) throws IgniteCheckedException {
+    public <R> R saveOrGet(IgniteFuture<R> fut) throws IgniteException {
         if (curFut != null) {
             curFut.set(fut);
 

Reply via email to